# Unit testing for Nepho

## Running unit tests

To run tests from the command line:

    $ pip install -r ci/requirements.txt
    $ python setup.py nosetests

## Writing unit tests

Use `tests/TEMPLATE_test.py` as a template.  Change 'TEMPLATE' to some meaningful descriptor.
